@@ -42,26 +42,37 @@
 
 namespace PDepend;
 
+use AppendIterator;
 use ArrayIterator;
 use GlobIterator;
+use InvalidArgumentException;
+use OutOfBoundsException;
 use PDepend\Input\CompositeFilter;
 use PDepend\Input\Filter;
 use PDepend\Input\Iterator;
+use PDepend\Metrics\Analyzer;
 use PDepend\Metrics\AnalyzerCacheAware;
 use PDepend\Metrics\AnalyzerFactory;
 use PDepend\Metrics\AnalyzerFilterAware;
 use PDepend\Report\CodeAwareGenerator;
+use PDepend\Report\ReportGenerator;
+use PDepend\Source\AST\ASTArtifactList;
 use PDepend\Source\AST\ASTArtifactList\ArtifactFilter;
 use PDepend\Source\AST\ASTArtifactList\CollectionArtifactFilter;
 use PDepend\Source\AST\ASTArtifactList\NullArtifactFilter;
+use PDepend\Source\AST\ASTNamespace;
 use PDepend\Source\ASTVisitor\ASTVisitor;
 use PDepend\Source\Builder\Builder;
 use PDepend\Source\Language\PHP\PHPBuilder;
 use PDepend\Source\Language\PHP\PHPParserGeneric;
 use PDepend\Source\Language\PHP\PHPTokenizerInternal;
+use PDepend\Source\Parser\ParserException;
 use PDepend\Source\Tokenizer\Tokenizer;
 use PDepend\Util\Cache\CacheFactory;
 use PDepend\Util\Configuration;
+use RecursiveDirectoryIterator;
+use RecursiveIteratorIterator;
+use RuntimeException;
 use SplFileObject;
 
 /**
@@ -88,7 +99,8 @@ class Engine
     /**
      * The system configuration.
      *
-     * @var   \PDepend\Util\Configuration
+     * @var Configuration
+     *
      * @since 0.10.0
      */
     protected $configuration = null;
@@ -117,49 +129,49 @@ class Engine
     /**
      * The used code node builder.
      *
-     * @var \PDepend\Source\Builder\Builder<\PDepend\Source\AST\ASTNamespace>|null
+     * @var PHPBuilder<ASTNamespace>|null
      */
     private $builder = null;
 
     /**
-     * Generated {@link \PDepend\Source\AST\ASTNamespace} objects.
+     * Generated {@link ASTNamespace} objects.
      *
-     * @var \PDepend\Source\AST\ASTNamespace[]
+     * @var ASTArtifactList<ASTNamespace>
      */
     private $namespaces = null;
 
     /**
-     * List of all registered {@link \PDepend\Report\ReportGenerator} instances.
+     * List of all registered {@link ReportGenerator} instances.
      *
-     * @var \PDepend\Report\ReportGenerator[]
+     * @var ReportGenerator[]
      */
     private $generators = array();
 
     /**
      * A composite filter for input files.
      *
-     * @var \PDepend\Input\CompositeFilter
+     * @var CompositeFilter
      */
     private $fileFilter = null;
 
     /**
      * A filter for namespace.
      *
-     * @var \PDepend\Source\AST\ASTArtifactList\ArtifactFilter
+     * @var ArtifactFilter
      */
     private $codeFilter = null;
 
     /**
      * Should the parse ignore doc comment annotations?
      *
-     * @var boolean
+     * @var bool
      */
     private $withoutAnnotations = false;
 
     /**
      * List or registered listeners.
      *
-     * @var \PDepend\ProcessListener[]
+     * @var ProcessListener[]
      */
     private $listeners = array();
 
@@ -171,32 +183,31 @@ class Engine
     private $options = array();
 
     /**
-     * List of all {@link \PDepend\Source\Parser\ParserException} that were caught during
+     * List of all {@link ParserException} that were caught during
      * the parsing process.
      *
-     * @var \PDepend\Source\Parser\ParserException[]
+     * @var ParserException[]
      */
     private $parseExceptions = array();
 
     /**
      * The configured cache factory.
      *
-     * @var   \PDepend\Util\Cache\CacheFactory
+     * @var CacheFactory
+     *
      * @since 1.0.0
      */
     private $cacheFactory;
 
     /**
-     * @var \PDepend\Metrics\AnalyzerFactory
+     * @var AnalyzerFactory
      */
     private $analyzerFactory;
 
     /**
      * Constructs a new php depend facade.
      *
-     * @param \PDepend\Util\Configuration      $configuration   The system configuration.
-     * @param \PDepend\Util\Cache\CacheFactory $cacheFactory
-     * @param \PDepend\Metrics\AnalyzerFactory $analyzerFactory
+     * @param Configuration $configuration The system configuration.
      */
     public function __construct(
         Configuration $configuration,
@@ -215,7 +226,8 @@ class Engine
     /**
      * Adds the specified directory to the list of directories to be analyzed.
      *
-     * @param  string $directory The php source directory.
+     * @param string $directory The php source directory.
+     *
      * @return void
      */
     public function addDirectory($directory)
@@ -223,7 +235,7 @@ class Engine
         $dir = realpath($directory);
 
         if ($dir === false || !is_dir($dir)) {
-            throw new \InvalidArgumentException("Invalid directory '{$directory}' added.");
+            throw new InvalidArgumentException("Invalid directory '{$directory}' added.");
         }
 
         $this->directories[] = $dir;
@@ -232,7 +244,8 @@ class Engine
     /**
      * Adds a single source code file to the list of files to be analysed.
      *
-     * @param  string $file The source file name.
+     * @param string $file The source file name.
+     *
      * @return void
      */
     public function addFile($file)
@@ -248,7 +261,7 @@ class Engine
         }
 
         if (!is_file($file)) {
-            throw new \InvalidArgumentException(sprintf('The given file "%s" does not exist.', $file));
+            throw new InvalidArgumentException(sprintf('The given file "%s" does not exist.', $file));
         }
 
         $this->files[] = realpath($file);
@@ -257,10 +270,11 @@ class Engine
     /**
      * Adds a logger to the output list.
      *
-     * @param  \PDepend\Report\ReportGenerator $generator The logger instance.
+     * @param ReportGenerator $generator The logger instance.
+     *
      * @return void
      */
-    public function addReportGenerator(\PDepend\Report\ReportGenerator $generator)
+    public function addReportGenerator(Report\ReportGenerator $generator)
     {
         $this->generators[] = $generator;
     }
@@ -268,7 +282,8 @@ class Engine
     /**
      * Adds a new input/file filter.
      *
-     * @param  \PDepend\Input\Filter $filter New input/file filter instance.
+     * @param Filter $filter New input/file filter instance.
+     *
      * @return void
      */
     public function addFileFilter(Filter $filter)
@@ -280,7 +295,6 @@ class Engine
      * Sets an additional code filter. These filters could be used to hide
      * external libraries and global stuff from the PDepend output.
      *
-     * @param  \PDepend\Source\AST\ASTArtifactList\ArtifactFilter $filter
      * @return void
      */
     public function setCodeFilter(ArtifactFilter $filter)
@@ -291,7 +305,8 @@ class Engine
     /**
      * Sets analyzer options.
      *
-     * @param  array<string, mixed> $options The analyzer options.
+     * @param array<string, mixed> $options The analyzer options.
+     *
      * @return void
      */
     public function setOptions(array $options = array())
@@ -312,7 +327,8 @@ class Engine
     /**
      * Adds a process listener.
      *
-     * @param  \PDepend\ProcessListener $listener The listener instance.
+     * @param ProcessListener $listener The listener instance.
+     *
      * @return void
      */
     public function addProcessListener(ProcessListener $listener)
@@ -326,7 +342,7 @@ class Engine
      * Analyzes the registered directories and returns the collection of
      * analyzed namespace.
      *
-     * @return \PDepend\Source\AST\ASTNamespace[]
+     * @return ASTArtifactList<ASTNamespace>
      */
     public function analyze()
     {
@@ -365,13 +381,13 @@ class Engine
     /**
      * Returns the number of analyzed php classes and interfaces.
      *
-     * @return integer
+     * @return int
      */
     public function countClasses()
     {
         if ($this->namespaces === null) {
             $msg = 'countClasses() doesn\'t work before the source was analyzed.';
-            throw new \RuntimeException($msg);
+            throw new RuntimeException($msg);
         }
 
         $classes = 0;
@@ -382,10 +398,10 @@ class Engine
     }
 
     /**
-     * Returns an <b>array</b> with all {@link \PDepend\Source\Parser\ParserException}
+     * Returns an <b>array</b> with all {@link ParserException}
      * that were caught during the parsing process.
      *
-     * @return \PDepend\Source\Parser\ParserException[]
+     * @return ParserException[]
      */
     public function getExceptions()
     {
@@ -395,13 +411,13 @@ class Engine
     /**
      *  Returns the number of analyzed namespaces.
      *
-     * @return integer
+     * @return int
      */
     public function countNamespaces()
     {
         if ($this->namespaces === null) {
             $msg = 'countNamespaces() doesn\'t work before the source was analyzed.';
-            throw new \RuntimeException($msg);
+            throw new RuntimeException($msg);
         }
 
         $count = 0;
@@ -416,36 +432,39 @@ class Engine
     /**
      * Returns the analyzed namespace for the given name.
      *
-     * @param  string $name
-     * @return \PDepend\Source\AST\ASTNamespace
-     * @throws \OutOfBoundsException
-     * @throws \RuntimeException
+     * @param string $name
+     *
+     * @throws OutOfBoundsException
+     * @throws RuntimeException
+     *
+     * @return ASTNamespace
      */
     public function getNamespace($name)
     {
         if ($this->namespaces === null) {
             $msg = 'getNamespace() doesn\'t work before the source was analyzed.';
-            throw new \RuntimeException($msg);
+            throw new RuntimeException($msg);
         }
         foreach ($this->namespaces as $namespace) {
             if ($namespace->getName() === $name) {
                 return $namespace;
             }
         }
-        throw new \OutOfBoundsException(sprintf('Unknown namespace "%s".', $name));
+        throw new OutOfBoundsException(sprintf('Unknown namespace "%s".', $name));
     }
 
     /**
      * Returns an array with the analyzed namespace.
      *
-     * @return \PDepend\Source\AST\ASTNamespace[]
-     * @throws \RuntimeException
+     * @throws RuntimeException
+     *
+     * @return ASTArtifactList<ASTNamespace>
      */
     public function getNamespaces()
     {
         if ($this->namespaces === null) {
             $msg = 'getNamespaces() doesn\'t work before the source was analyzed.';
-            throw new \RuntimeException($msg);
+            throw new RuntimeException($msg);
         }
         return $this->namespaces;
     }
@@ -453,7 +472,8 @@ class Engine
     /**
      * Send the start parsing process event.
      *
-     * @param  \PDepend\Source\Builder\Builder<\PDepend\Source\AST\ASTNamespace> $builder The used node builder instance.
+     * @param Builder<ASTNamespace> $builder The used node builder instance.
+     *
      * @return void
      */
     protected function fireStartParseProcess(Builder $builder)
@@ -466,7 +486,8 @@ class Engine
     /**
      * Send the end parsing process event.
      *
-     * @param  \PDepend\Source\Builder\Builder<\PDepend\Source\AST\ASTNamespace> $builder The used node builder instance.
+     * @param Builder<ASTNamespace> $builder The used node builder instance.
+     *
      * @return void
      */
     protected function fireEndParseProcess(Builder $builder)
@@ -479,7 +500,6 @@ class Engine
     /**
      * Sends the start file parsing event.
      *
-     * @param  \PDepend\Source\Tokenizer\Tokenizer $tokenizer
      * @return void
      */
     protected function fireStartFileParsing(Tokenizer $tokenizer)
@@ -492,7 +512,6 @@ class Engine
     /**
      * Sends the end file parsing event.
      *
-     * @param  \PDepend\Source\Tokenizer\Tokenizer $tokenizer
      * @return void
      */
     protected function fireEndFileParsing(Tokenizer $tokenizer)
@@ -585,7 +604,7 @@ class Engine
 
             try {
                 $parser->parse();
-            } catch (\PDepend\Source\Parser\ParserException $e) {
+            } catch (ParserException $e) {
                 $this->parseExceptions[] = $e;
             }
             $this->fireEndFileParsing($tokenizer);
@@ -636,15 +655,15 @@ class Engine
      * This method will create an iterator instance which contains all files
      * that are part of the parsing process.
      *
-     * @return \Iterator<int, string>
+     * @return ArrayIterator<int, string>
      */
     private function createFileIterator()
     {
         if (count($this->directories) === 0 && count($this->files) === 0) {
-            throw new \RuntimeException('No source directory and file set.');
+            throw new RuntimeException('No source directory and file set.');
         }
 
-        $fileIterator = new \AppendIterator();
+        $fileIterator = new AppendIterator();
 
         foreach ($this->files as $file) {
             $fileIterator->append(
@@ -657,10 +676,10 @@ class Engine
         foreach ($this->directories as $directory) {
             $fileIterator->append(
                 new Iterator(
-                    new \RecursiveIteratorIterator(
-                        new \RecursiveDirectoryIterator(
+                    new RecursiveIteratorIterator(
+                        new RecursiveDirectoryIterator(
                             $directory . '/',
-                            \RecursiveDirectoryIterator::FOLLOW_SYMLINKS
+                            RecursiveDirectoryIterator::FOLLOW_SYMLINKS
                         )
                     ),
                     $this->fileFilter,
@@ -696,7 +715,8 @@ class Engine
 
     /**
      * @param array<string, mixed> $options
-     * @return \PDepend\Metrics\Analyzer[]
+     *
+     * @return Analyzer[]
      */
     private function createAnalyzers($options)
     {
@@ -725,6 +745,7 @@ class Engine
 
     /**
      * @param string $path
+     *
      * @return bool
      */
     private function isPhpStream($path)
