@@ -168,6 +168,17 @@ class ASTNamespace extends AbstractASTArtifact
         return $this->getTypesOfType('PDepend\\Source\\AST\\ASTClass');
     }
 
+    /**
+     * Returns an iterator with all {@link ASTEnum}
+     * instances within this namespace.
+     *
+     * @return ASTArtifactList<ASTEnum>
+     */
+    public function getEnums()
+    {
+        return $this->getTypesOfType('PDepend\\Source\\AST\\ASTEnum');
+    }
+
     /**
      * Returns an iterator with all {@link ASTInterface}
      * instances within this namespace.
@@ -195,7 +206,7 @@ class ASTNamespace extends AbstractASTArtifact
     {
         $types = array();
         foreach ($this->types as $type) {
-            if (get_class($type) === $className) {
+            if ($type instanceof $className && get_class($type) === $className) {
                 $types[] = $type;
             }
         }
