@@ -38,6 +38,7 @@
  *
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ *
  * @since 2.3
  */
 
@@ -45,7 +46,10 @@ namespace PDepend\Source\Language\PHP;
 
 use PDepend\Source\AST\ASTAllocationExpression;
 use PDepend\Source\AST\ASTExpression;
+use PDepend\Source\AST\ASTFormalParameter;
 use PDepend\Source\AST\ASTNode;
+use PDepend\Source\AST\ASTType;
+use PDepend\Source\Parser\UnexpectedTokenException;
 use PDepend\Source\Tokenizer\Tokens;
 
 /**
@@ -53,13 +57,15 @@ use PDepend\Source\Tokenizer\Tokens;
  *
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ *
  * @since 2.3
  */
 abstract class PHPParserVersion70 extends PHPParserVersion56
 {
     /**
-     * @param integer $tokenType
-     * @return boolean
+     * @param int $tokenType
+     *
+     * @return bool
      */
     protected function isConstantName($tokenType)
     {
@@ -138,7 +144,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * @param integer $tokenType
+     * @param int $tokenType
+     *
      * @return bool
      */
     protected function isMethodName($tokenType)
@@ -152,7 +159,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * @param integer $tokenType
+     * @param int $tokenType
+     *
      * @return bool
      */
     protected function isTypeHint($tokenType)
@@ -167,7 +175,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * @return \PDepend\Source\AST\ASTNode
+     * @return ASTNode
      */
     protected function parsePostfixIdentifier()
     {
@@ -183,11 +191,6 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
         return $this->parseOptionalIndexExpression($node);
     }
 
-    /**
-     * @template T of \PDepend\Source\AST\ASTCallable
-     * @param T $callable
-     * @return T
-     */
     protected function parseCallableDeclarationAddition($callable)
     {
         $this->consumeComments();
@@ -204,7 +207,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * @return \PDepend\Source\AST\ASTType
+     * @return ASTType
      */
     protected function parseEndReturnTypeHint()
     {
@@ -221,7 +224,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * @return \PDepend\Source\AST\ASTType
+     * @return ASTType
      */
     protected function parseReturnTypeHint()
     {
@@ -230,12 +233,6 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
         return $this->parseEndReturnTypeHint();
     }
 
-    /**
-     * Parses a type hint that is valid in the supported PHP version.
-     *
-     * @return \PDepend\Source\AST\ASTNode
-     * @since 2.3
-     */
     protected function parseTypeHint()
     {
         switch ($this->tokenizer->peek()) {
@@ -263,7 +260,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
      * Parses any expression that is surrounded by an opening and a closing
      * parenthesis
      *
-     * @return \PDepend\Source\AST\ASTExpression
+     * @return ASTExpression
      */
     protected function parseParenthesisExpression()
     {
@@ -289,10 +286,11 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     }
 
     /**
-     * Tests if the given image is a PHP 7 type hint.
+     * Tests if the given image is a PHP 7.0 type hint.
      *
      * @param string $image
-     * @return boolean
+     *
+     * @return bool
      */
     protected function isScalarOrCallableTypeHint($image)
     {
@@ -314,7 +312,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
      * Parses a scalar type hint or a callable type hint.
      *
      * @param string $image
-     * @return \PDepend\Source\AST\ASTType|false
+     *
+     * @return ASTType|false
      */
     protected function parseScalarOrCallableTypeHint($image)
     {
@@ -337,8 +336,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     /**
      * Parse the type reference used in an allocation expression.
      *
-     * @param \PDepend\Source\AST\ASTAllocationExpression $allocation
-     * @return \PDepend\Source\AST\ASTNode
+     * @return ASTNode
+     *
      * @since 2.3
      */
     protected function parseAllocationExpressionTypeReference(ASTAllocationExpression $allocation)
@@ -350,9 +349,11 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     /**
      * Attempts to the next sequence of tokens as an anonymous class and adds it to the allocation expression
      *
-     * @param \PDepend\Source\AST\ASTAllocationExpression $allocation
+     * @template T of ASTAllocationExpression
      *
-     * @return null|\PDepend\Source\AST\ASTAnonymousClass
+     * @param T $allocation
+     *
+     * @return T|null
      */
     protected function parseAnonymousClassDeclaration(ASTAllocationExpression $allocation)
     {
@@ -412,10 +413,6 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
         return $allocation;
     }
 
-    /**
-     * @param \PDepend\Source\AST\ASTNode $node
-     * @return \PDepend\Source\AST\ASTNode
-     */
     protected function parseOptionalMemberPrimaryPrefix(ASTNode $node)
     {
         $this->consumeComments();
@@ -431,10 +428,6 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
         return $node;
     }
 
-    /**
-     * @param \PDepend\Source\AST\ASTExpression $expr
-     * @return \PDepend\Source\AST\ASTExpression
-     */
     protected function parseParenthesisExpressionOrPrimaryPrefixForVersion(ASTExpression $expr)
     {
         $this->consumeComments();
@@ -456,8 +449,10 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
      * in the base version. In this method you can implement version specific
      * expressions.
      *
-     * @return \PDepend\Source\AST\ASTNode
-     * @throws \PDepend\Source\Parser\UnexpectedTokenException
+     * @throws UnexpectedTokenException
+     *
+     * @return ASTNode
+     *
      * @since 2.3
      */
     protected function parseOptionalExpressionForVersion()
@@ -469,7 +464,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
     /**
      * In this method we implement parsing of PHP 7.0 specific expressions.
      *
-     * @return \PDepend\Source\AST\ASTNode|null
+     * @return ASTNode|null
+     *
      * @since 2.3
      */
     protected function parseExpressionVersion70()
@@ -506,7 +502,8 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
      * //               --  -------
      * </code>
      *
-     * @return \PDepend\Source\AST\ASTFormalParameter
+     * @return ASTFormalParameter
+     *
      * @since 2.0.7
      */
     protected function parseFormalParameter()
@@ -527,6 +524,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
 
     /**
      * @param array<string> $fragments
+     *
      * @return void
      */
     protected function parseUseDeclarationForVersion(array $fragments)
@@ -542,6 +540,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
 
     /**
      * @param array<string> $fragments
+     *
      * @return void
      */
     protected function parseUseDeclarationVersion70(array $fragments)
@@ -593,6 +592,7 @@ abstract class PHPParserVersion70 extends PHPParserVersion56
 
     /**
      * @param array<string> $previousElements
+     *
      * @return string|null
      */
     protected function parseQualifiedNameElement(array $previousElements)
